@@ -32,7 +32,7 @@
 #include "event.h"
 #include "visitor.h"
 #include "utils_p.h"
-#include "kcalcore_debug.h"
+#include "kcalendarcore_debug.h"
 
 #include <QDate>
 
